package X11::Aosd;

use 5.008;
use strict;
use warnings;
use Carp;

require Exporter;
use AutoLoader;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use X11::Aosd ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw(
	COORDINATE_CENTER
	COORDINATE_MAXIMUM
	COORDINATE_MINIMUM
	TRANSPARENCY_COMPOSITE
	TRANSPARENCY_FAKE
	TRANSPARENCY_NONE
) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(
	COORDINATE_CENTER
	COORDINATE_MAXIMUM
	COORDINATE_MINIMUM
	TRANSPARENCY_COMPOSITE
	TRANSPARENCY_FAKE
	TRANSPARENCY_NONE
);

our $VERSION = '0.01';

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.

    my $constname;
    our $AUTOLOAD;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    croak "&X11::Aosd::constant not defined" if $constname eq 'constant';
    my ($error, $val) = constant($constname);
    if ($error) { croak $error; }
    {
	no strict 'refs';
	# Fixed between 5.005_53 and 5.005_61
#XXX	if ($] >= 5.00561) {
#XXX	    *$AUTOLOAD = sub () { $val };
#XXX	}
#XXX	else {
	    *$AUTOLOAD = sub { $val };
#XXX	}
    }
    goto &$AUTOLOAD;
}

require XSLoader;
XSLoader::load('X11::Aosd', $VERSION);

# Preloaded methods go here.

#-- object (de)allocators

sub new {
    my $class = shift;
    return bless \aosd_new(), $class;
}

sub DESTROY {
    my $self = shift;
    aosd_destroy($$self);
    1;
}

#-- object inspectors

sub get_transparency {
    my $self = shift;
    aosd_get_transparency($$self);
}

sub get_geometry {
    my $self = shift;
    aosd_get_geometry($$self);
}

sub get_screen_size {
    my $self = shift;
    aosd_get_screen_size($$self);
}

sub get_is_shown {
    my $self = shift;
    aosd_get_is_shown($$self);
}

#-- object configurators

sub set_transparency {
    my $self = shift;
    my ($mode) = @_;

    croak "Illegal transparency mode" unless
        $mode == TRANSPARENCY_NONE() || 
        $mode == TRANSPARENCY_FAKE() ||
        $mode == TRANSPARENCY_COMPOSITE();

    aosd_set_transparency($$self, $mode);
}

sub set_geometry {
    my $self = shift;
    aosd_set_geometry($$self, @_);
}

sub set_position {
    my $self = shift;
    my ($pos, $width, $height) = @_;
    
    aosd_set_position($$self, $pos, $width, $height);
}

sub set_position_offset {
    my $self = shift;
    my ($x_offset, $y_offset) = @_;
    
    aosd_set_position_offset($$self, $x_offset, $y_offset);
}

#-- object manipulators

sub render {
    my $self = shift;
    aosd_render($$self);
}

sub show {
    my $self = shift;
    aosd_show($$self);
}

sub hide {
    my $self = shift;
    aosd_hide($$self);
}

#-- X main loop processing
sub loop_once {
    my $self = shift;
    aosd_loop_once($$self);
}

sub loop_for {
    my $self = shift;
    my ($ms) = @_;
    aosd_loop_for($$self, $ms);
}

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

X11::Aosd - libaosd binding for Cairo powered on screen display

=head1 SYNOPSIS

  use X11::Aosd;

  #-- [todo: write more]

=head1 DESCRIPTION

This Perl extensions binds the aosd library, which can be found here:

  http://www.atheme.org/projects/libaosd.shtml

[todo: write more]

=head2 EXPORT

None by default.

=head2 Exportable constants

  COORDINATE_CENTER
  COORDINATE_MAXIMUM
  COORDINATE_MINIMUM
  TRANSPARENCY_COMPOSITE
  TRANSPARENCY_FAKE
  TRANSPARENCY_NONE

=head1 SEE ALSO

[todo: write more]

=head1 AUTHOR

Joern Reder, E<lt>joern AT zyn DOT deE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 by Joern Reder

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

=cut
