# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl X11-Aosd.t'

#########################

# change 'tests => 2' to 'tests => last_test_to_print';

use strict;
use Test::More tests => 13;
use Data::Dumper;
BEGIN { use_ok('X11::Aosd') };

my $fail = 0;
foreach my $constname (qw(
	COORDINATE_CENTER COORDINATE_MAXIMUM COORDINATE_MINIMUM
	TRANSPARENCY_COMPOSITE TRANSPARENCY_FAKE TRANSPARENCY_NONE)) {
  next if (eval "my \$a = $constname; 1");
  if ($@ =~ /^Your vendor has not defined X11::Aosd macro $constname/) {
    print "# pass: $@";
  } else {
    print "# fail: $@";
    $fail = 1;
  }

}

ok( $fail == 0 , 'Constants' );

#########################

# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.

my $aosd = X11::Aosd->new;
ok( $aosd->isa("X11::Aosd"), 'new X11::Aosd()');

my $trans = $aosd->get_transparency;
ok ( $trans == TRANSPARENCY_NONE || 
     $trans == TRANSPARENCY_FAKE ||
     $trans == TRANSPARENCY_COMPOSITE, "get_transparency()");

$aosd->set_transparency(TRANSPARENCY_NONE);
ok ( $trans == TRANSPARENCY_NONE, "set_transparency()");

eval { $aosd->set_transparency(4711) };
ok ( $@, 'croak @ set_transparency(illegal mode)');

$aosd->set_geometry(100,200,300,400);

my @geo = $aosd->get_geometry;
ok ( $geo[0]==100 && $geo[1]==200 && $geo[2]==300 && $geo[3]==400,
     "set_geometry() && get_geometry()");

my @screen = $aosd->get_screen_size;
ok ( $screen[0]>0 && $screen[1]>0, "get_screen_size()");

$aosd->set_position(0, 333, 444);
@geo = $aosd->get_geometry;
ok ( $geo[0]==0 && $geo[1]==0 && $geo[2]==333 && $geo[3]==444,
     "set_position()");

$aosd->set_position_offset(67, 56);
@geo = $aosd->get_geometry;
ok ( $geo[0]==67 && $geo[1]==56 && $geo[2]==333 && $geo[3]==444,
     "set_position_offset()");

# $aosd->render;

$aosd->show;
ok ( $aosd->get_is_shown, "show() && get_is_shown()");

$aosd->loop_once;

my $time = time;
$aosd->loop_for(1200);
ok ( time-$time>0, "loop_for(2000)");

$aosd->hide;
ok ( !$aosd->get_is_shown, "hide() && !get_is_shown()");

